package com.yeejoin.amos.boot.module.jg.biz.service;


import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * JG表格数据导出接口类
 */
public interface IJgTableDataExportService {

    void gen(String jsonName, String voName,String tableName);

    void certificate(HttpServletResponse response, List<String> ids);

    void maintenance(HttpServletResponse response, List<String> ids);

    void installation(HttpServletResponse response, List<String> ids);

    void maintain(HttpServletResponse response, List<String> ids);

    void reform(HttpServletResponse response, List<String> ids);

    void transfer(HttpServletResponse response, List<String> ids);

    void registration(HttpServletResponse response, List<String> ids);

    void changeRegistrationUnit(HttpServletResponse response, List<String> ids);

    void changeRegistrationReform(HttpServletResponse response, List<String> ids);

    void enableDisable(HttpServletResponse response, List<String> ids);

    void scrapCancel(HttpServletResponse response, List<String> ids);

    void changeRegistrationTransfer(HttpServletResponse response, List<String> ids);

    void changeRegistrationName(HttpServletResponse response, List<String> ids);

    void vehicleInformation(HttpServletResponse response, List<String> ids);

    void changeVehicleRegistrationUnit(HttpServletResponse response, List<String> ids);

    void unregulatedEquip(HttpServletResponse response, List<String> ids);

    void manageEquipment(HttpServletResponse response, List<String> ids);

    void equipTransfer(HttpServletResponse response, List<String> ids);

}
